Test program running on MAX32625MBED. Control through USB Serial commands using a terminal emulator such as teraterm or putty.

Dependencies:   MaximTinyTester MAX11410 CmdLine USBDevice

Revision:
51:15d9a9e0b623
Parent:
49:5bfa51523bc2
Child:
52:d3fb6f1722bf
--- a/Test_Menu_MAX11410.cpp	Fri Jan 17 22:08:40 2020 +0000
+++ b/Test_Menu_MAX11410.cpp	Wed Jan 22 07:57:46 2020 +0000
@@ -335,7 +335,7 @@
 // CODE GENERATOR:           CommandPre ''
 // CODE GENERATOR:           CommandDocParamIn ''
 // CODE GENERATOR:           CommandDocParamOut ''
-// CODE GENERATOR:           CommandPost '@post AINcode[0..9]: measurement result LSB code'
+// CODE GENERATOR:           CommandPost '@post AINcode[0..10]: measurement result LSB code'
 // CODE GENERATOR:           CommandReturn '@return 1 on success; 0 on failure'
 // CODE GENERATOR: MAX11410 Command Name = Measure_Voltage (MAX11410_AINP_SEL_enum_t ainp, MAX11410_AINN_SEL_enum_t ainn) --> double
 // CODE GENERATOR: Menu item hint description Menu item 'V'
@@ -540,7 +540,7 @@
 // CODE GENERATOR: testMenuGlobalArgsDict['data0']['usedByCommandName'] = 'None'
 // CODE GENERATOR: testMenuGlobalArgsDict['data0']['usedBytestMenuItemName'] = 'None'
 
 // CODE GENERATOR: testMenuGlobalArgsDict skip array property g_MAX11410_device.AINcode[10]
 
 // CODE GENERATOR: scan testMenuCommand list for items that can be shortened to single character
 // CODE GENERATOR: multiple commands begin with character 'T'
@@ -854,8 +854,8 @@
 // CODE GENERATOR: @ command print uint32_t g_MAX11410_device.data0
                     cmdLine.serial().printf("data0 = ");
                     cmdLine.serial().printf("%d = 0x%8.8x\n", g_MAX11410_device.data0, g_MAX11410_device.data0);
-// CODE GENERATOR: @ command print uint32_t array g_MAX11410_device.AINcode[0..9]
-                for(int index = 0; (index < 10) && (index < 16); index++) {
+// CODE GENERATOR: @ command print uint32_t array g_MAX11410_device.AINcode[0..10]
+                for(int index = 0; (index < 11) && (index < 16); index++) {
                     cmdLine.serial().printf("AINcode[%d] = ", index);
                     cmdLine.serial().printf("%d = 0x%8.8x\n", g_MAX11410_device.AINcode[index], g_MAX11410_device.AINcode[index]);
                 }
@@ -915,7 +915,7 @@
 // CODE GENERATOR:           CommandPre ''
 // CODE GENERATOR:           CommandDocParamIn ''
 // CODE GENERATOR:           CommandDocParamOut ''
-// CODE GENERATOR:           CommandPost '@post AINcode[0..9]: measurement result LSB code'
+// CODE GENERATOR:           CommandPost '@post AINcode[0..10]: measurement result LSB code'
 // CODE GENERATOR:           CommandReturn '@return 1 on success; 0 on failure'
         // case '$': // (single character) (testMenuFirstCharHandler="None")
         case '$':
@@ -929,7 +929,7 @@
                     // @Pre=''
                     // @Param[in]=''
                     // @Param[out]=''
-                    // @Post='@post AINcode[0..9]: measurement result LSB code'
+                    // @Post='@post AINcode[0..10]: measurement result LSB code'
                     // displayPost=''
                     // @Return='@return 1 on success; 0 on failure'
                     cmdLine.serial().printf("Read_All_Voltages");
@@ -540,7 +540,7 @@
 // CODE GENERATOR: testMenuGlobalArgsDict['data0']['usedBytestMenuItemName'] = 'None'
 
-// CODE GENERATOR: testMenuGlobalArgsDict skip array property g_MAX11410_device.AINcode[10]
+// CODE GENERATOR: testMenuGlobalArgsDict skip array property g_MAX11410_device.AINcode[11]
 
 // CODE GENERATOR: scan testMenuCommand list for items that can be shortened to single character